@@ -1,7 +1,9 @@
 """Middleware to report application status to the infrastructure."""
 import logging
+import os
 
 from django.http import HttpResponse
+from django.http import JsonResponse
 
 
 class HealthCheckMiddleware:
@@ -20,6 +22,8 @@ class HealthCheckMiddleware:
                 response = self.ready(request)
             elif request.path == "/.well-known/probe/live":
                 response = self.live(request)
+            elif request.path == '/.well-known/metadata':
+                response = self.metadata(request)
         return response or self.get_response(request)
 
     def live(self, request):
@@ -28,6 +32,15 @@ class HealthCheckMiddleware:
             request.META['REMOTE_ADDR'])
         return HttpResponse("OK")
 
+    def metadata(self, request):
+        """Return a datastructure with information about the current
+        application.
+        """
+        dto = {
+            'commit': os.getenv('VCS_COMMIT_HASH')
+        }
+        return JsonResponse(dto)
+
     def ready(self, request):
         """Respond with ``200 OK`` if all services are operational."""
         self.logger.info("Received readyness probe from %s",
